desiredAccuracy property
Specify the desired accuracy of the geolocation system.
| Name | Location Providers | Description |
|---|---|---|
desiredAcuracyNavigation |
(iOS only) GPS + Wifi + Cellular | Highest power; highest accuracy |
desiredAcuracyHigh |
GPS + Wifi + Cellular | Highest power; highest accuracy |
desiredAcuracyMedium |
Wifi + Cellular | Medium power; medium accuracy; |
desiredAcuracyLow |
Wifi (low power) + Cellular | Lower power; No GPS |
desiredAcuracyVeryLow |
Cellular only | Lowest power; lowest accuracy |
desiredAcuracyLowest |
(iOS only) Lowest power; lowest accuracy |
Note: Only desiredAcuracyHigh uses GPS. speed, heading, and altitude are available only from GPS.
For platform-specific information about location accuracy, see the corresponding API docs:
Implementation
int? desiredAccuracy;